==============================================================================
CCIAA Intranet Workflow
==============================================================================

Sets as default, a workflow with a double-level revision. This is specifically made for Chamber of commerce sites.

Installation
------------

Install cciaa.topic_view by adding it to your buildout::

    [buildout]
    ...
    eggs =
        cciaa.intranetworkflow


and then running ``bin/buildout``

After that, you will found a new installable product: CCIAA Workflow

Dependency
----------

Tested on Plone 4.3.x

Contribute
----------

- Issue Tracker: https://github.com/PloneGov-IT/cciaa.topic_view/issues
- Source Code: https://github.com/PloneGov-IT/cciaa.topic_view

Credits
-------

Developed with the support of `Camera di Commercio di Ferrara`__;
Camera di Commercio di Ferrara supports the `PloneGov initiative`__.

.. image:: http://www.fe.camcom.it/cciaa-logo.png/
   :alt: CCIAA Ferrara - logo

__ http://www.fe.camcom.it/
__ http://www.plonegov.it/

Authors
-------

This product was developed by RedTurtle Technology team.

.. image:: http://www.redturtle.it/redturtle_banner.png
   :alt: RedTurtle Technology Site
   :target: http://www.redturtle.it/
